@@ -53,12 +53,12 @@ def install(buildout=None):
                 log.debug('Found an egg in %s' % egg_path)
 
                 if egg_path not in buildout['buildout']['develop']:
-                    buildout['buildout']['develop'] += ' %s' % egg_path
+                    buildout['buildout']['develop'] += '\n%s' % egg_path
                     log.debug("Added %s to develop section" % egg_path)
 
                 for name in instance_part_names:
                     if egg_name not in buildout[name]['eggs']:
-                        buildout[name]['eggs'] += ' %s' % egg_name
+                        buildout[name]['eggs'] += '\n%s' % egg_name
                         log.debug("Added %s to the egg section of [%s]" % (egg_name, name))
 
                     if egg_name in zcml_tops:
